@@ -270,12 +270,12 @@ class RequestHandler(tornado.web.RequestHandler):
         # mail client
         # _smtp_config = self.application.settings.get('smtp')
         #
-        # if _smtp_config:
-        #     self.smtp = MailClient2(_smtp_config)
-        # else:
-        #     self.smtp = None
+        if _smtp_config:
+            self.smtp = MailClient2(_smtp_config)
+        else:
+            self.smtp = None
 
-        self.smtp=None
+        # self.smtp=None
         # self.db = None
         self.acct_db = None
         # self.cache_db=None
